vfbLib.parsers.truetype.TrueTypeInfoParser
==========================================

.. currentmodule:: vfbLib.parsers.truetype

.. autoclass:: TrueTypeInfoParser
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~TrueTypeInfoParser.__init__
      ~TrueTypeInfoParser.assert_unique
      ~TrueTypeInfoParser.parse
      ~TrueTypeInfoParser.parse_hex
      ~TrueTypeInfoParser.read_double
      ~TrueTypeInfoParser.read_doubles
      ~TrueTypeInfoParser.read_float
      ~TrueTypeInfoParser.read_floats
      ~TrueTypeInfoParser.read_int16
      ~TrueTypeInfoParser.read_int32
      ~TrueTypeInfoParser.read_int8
      ~TrueTypeInfoParser.read_str
      ~TrueTypeInfoParser.read_str_all
      ~TrueTypeInfoParser.read_uint16
      ~TrueTypeInfoParser.read_uint32
      ~TrueTypeInfoParser.read_uint8
      ~TrueTypeInfoParser.read_value
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~TrueTypeInfoParser.encoding
      ~TrueTypeInfoParser.master_count
      ~TrueTypeInfoParser.stream
      ~TrueTypeInfoParser.ttStemsH_count
      ~TrueTypeInfoParser.ttStemsV_count
   
   